summaryrefslogtreecommitdiffstats
path: root/src/H5Oprivate.h
diff options
context:
space:
mode:
authorQuincey Koziol <koziol@hdfgroup.org>2010-03-25 12:49:23 (GMT)
committerQuincey Koziol <koziol@hdfgroup.org>2010-03-25 12:49:23 (GMT)
commit49826ea52c056858a0ec1aac6188dcbce15b7798 (patch)
treedd162f823379e3d49f28806a2ee60149b34a78d0 /src/H5Oprivate.h
parentd0c4c5741e4c29e4dc9e67062e2692d6316e2056 (diff)
downloadhdf5-49826ea52c056858a0ec1aac6188dcbce15b7798.zip
hdf5-49826ea52c056858a0ec1aac6188dcbce15b7798.tar.gz
hdf5-49826ea52c056858a0ec1aac6188dcbce15b7798.tar.bz2
[svn-r18452] Description:
Finish renaming cache-related files & symbols on metadata journaling branch. Metadata cache-related symbols/files with no suffix now have a '1' suffix and symbols/files with a '2' suffix now have no suffix. Tested on: Mac OS X/32 10.6.2 (amazon) w/debug, prod & parallel (h5committest not required on this branch)
Diffstat (limited to 'src/H5Oprivate.h')
-rw-r--r--src/H5Oprivate.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/H5Oprivate.h b/src/H5Oprivate.h
index 657b3b5..a960ff8 100644
--- a/src/H5Oprivate.h
+++ b/src/H5Oprivate.h
@@ -37,7 +37,7 @@
#include "H5Spublic.h" /* Dataspace functions */
/* Private headers needed by this file */
-#include "H5AC2private.h" /* Metadata cache */
+#include "H5ACprivate.h" /* Metadata cache */
#include "H5Fprivate.h" /* File access */
#include "H5SLprivate.h" /* Skip lists */
#include "H5Tprivate.h" /* Datatype functions */
@@ -532,7 +532,7 @@ typedef uint32_t H5O_refcount_t; /* Contains # of links to object, if >1
* The value of this field is undefined unless mdc_jnl_enabled is TRUE.
*
* mdc_jnl_file_name: Array of char of length
* H5C2__MAX_JOURNAL_FILE_NAME_LEN + 1 used to store the journal
* file path.
*
* The value of this field is undefined unless mdc_jnl_enabled is TRUE.
@@ -546,7 +546,7 @@ typedef struct H5O_mdj_msg_t {
hbool_t mdc_jnl_enabled;
int32_t mdc_jnl_magic;
size_t mdc_jnl_file_name_len;
- char mdc_jnl_file_name[H5C2__MAX_JOURNAL_FILE_NAME_LEN + 1];
+ char mdc_jnl_file_name[H5C__MAX_JOURNAL_FILE_NAME_LEN + 1];
} H5O_mdj_msg_t;
@@ -596,7 +596,7 @@ H5_DLL herr_t H5O_create(H5F_t *f, hid_t dxpl_id, size_t size_hint,
H5_DLL herr_t H5O_open(H5O_loc_t *loc);
H5_DLL herr_t H5O_close(H5O_loc_t *loc);
H5_DLL int H5O_link(const H5O_loc_t *loc, int adjust, hid_t dxpl_id);
-H5_DLL H5O_t *H5O_protect(const H5O_loc_t *loc, hid_t dxpl_id, H5AC2_protect_t prot);
+H5_DLL H5O_t *H5O_protect(const H5O_loc_t *loc, hid_t dxpl_id, H5AC_protect_t prot);
H5_DLL herr_t H5O_pin(H5O_t *oh);
H5_DLL herr_t H5O_unpin(H5O_t *oh);
H5_DLL herr_t H5O_unprotect(const H5O_loc_t *loc, hid_t dxpl_id, H5O_t *oh,
@@ -532,7 +532,7 @@ typedef uint32_t H5O_refcount_t; /* Contains # of links to object, if >1
*
* mdc_jnl_file_name: Array of char of length
- * H5C2__MAX_JOURNAL_FILE_NAME_LEN + 1 used to store the journal
+ * H5C__MAX_JOURNAL_FILE_NAME_LEN + 1 used to store the journal
* file path.
*